.. _msl-${msl-package-lower}-welcome:

MSL-${msl-package}
${=}

Write the documentation for **MSL-${msl-package}**.

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Release Notes <changelog>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
